<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<dependencies>
<dependency catalog="qtbase_sv"/>
<dependency catalog="qtmultimedia_sv"/>
</dependencies>
</TS>
